@@ -1,4 +1,5 @@
 import os
+from typing import List
 
 import aria2p
 import requests
@@ -108,10 +109,10 @@ class Commander:
             else:
                 print(i.name, end='\t')
 
-    def get_path_list(self, path='root') -> list[FileInfo]:
+    def get_path_list(self, path='root') -> List[FileInfo]:
         return self._path_list.get_path_list(path, update=False)
 
-    def get_fid_list(self, file_id='root') -> list[FileInfo]:
+    def get_fid_list(self, file_id='root') -> List[FileInfo]:
         return self._path_list.get_fid_list(file_id, update=False)
 
     def tree(self, path='root', stdout=sys.stdout):
